.. _linux.base_objects_mc:

##################
linux.base_objects
##################

This Model Component provides some basic functionality common to all Linux hosts, such as setting the hostname and configuring IP addresses.

**Model Component Dependencies:**
    * :ref:`base_objects_mc`

*****************
Available Objects
*****************

.. automodule:: linux.base_objects
    :members:
    :undoc-members:
    :special-members:
    :private-members:
    :show-inheritance:
    :exclude-members: __dict__,__weakref__,__module__
